#
# spec file for package sblim-cmpi-nfsv3
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           sblim-cmpi-nfsv3
Url:            http://sblim.wiki.sourceforge.net/
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  openssl-devel
BuildRequires:  pam-devel
BuildRequires:  sblim-cmpi-base-devel
BuildRequires:  sblim-indication_helper-devel
BuildRequires:  sblim-sfcb
BuildRequires:  sblim-testsuite
%if 0%{?suse_version}
BuildRequires:  openslp-devel
%endif
Summary:        SBLIM CMPI NFSv3 Instrumentation
License:        EPL-1.0
Group:          System/Management
Version:        1.1.1
Release:        3.3
Requires:       sblim-cmpi-base >= 1.2.3
Requires:       cim-server, cim-schema
Source:         http://prdownloads.sourceforge.net/sblim/sblim-cmpi-nfsv3-%{version}.tar.bz2
Patch:          0001-Missing-fclose-fix.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#!BuildIgnore:  tog-pegasus

%description
Standards Based Linux NFSv3 Instrumentation Providers



Authors:
--------
    SBLIM Project

%prep
%setup -n %{name}-%{version}
%patch -p1

%build
%configure --disable-static
%{__make}

%install
%if 0%{?suse_version}
%makeinstall docdir=%{_docdir}/%{name}
%else
make install DESTDIR=%{buildroot} docdir=%{_docdir}/%{name}-%{version}
%endif
rm %buildroot%_libdir/cmpi/*.la
rm %buildroot%_libdir/*.la

%clean
%{__rm} -rf %{buildroot}

%define PEGASUS_MOF CIM_SystemSetting,CIM_NFS,CIM_SystemConfiguration,CIM_SystemSettingContext

%post
# compile MOF
/sbin/ldconfig
# Register Schema and Provider - this is higly provider specific  
# tog-pegasus needs some schemes registered first  
if [ -x /usr/bin/peg-loadmof.sh ]; then  
    peg-loadmof.sh -n root/cimv2 /usr/share/mof/cim-current/*/{%{PEGASUS_MOF}}.mof  
    rctog-pegasus try-restart  
fi  
# and then following script can handle registration for various providers  
d=%{_datadir}/%{name}
$d/provider-register.sh -r $d/*.registration -m $d/*.mof

%preun
if [ "$1" = "0" ]; then
  d=%{_datadir}/%{name}
  $d/provider-register.sh -d -r $d/*.registration -m $d/*.mof
fi

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_libdir}/cmpi/*.so
%{_libdir}/*.so
%{_datadir}/sblim-testsuite/*
%{_datadir}/%{name}/
%doc COPYING
%if 0%{?suse_version}
%doc %{_docdir}/%{name}
%else
%doc %{_docdir}/%{name}-%{version}
%endif

%changelog
* Fri Apr 11 2014 kkaempf@suse.com
- install COPYING
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Wed Sep  7 2011 kkaempf@suse.com
- Fix resource leak
  if fopen() is successful and valid_file() not, file is not closed
  (Pavel Raiskup <praiskup@redhat.com>)
* Wed Sep  7 2011 kkaempf@suse.com
- update to 1.1.1
  - Features:
  - 3299507 obtain fully qualified hostname using etab entry
  - Bugs:
  - 3275169 bash error reported in provider bootstrap scripts
  - 3303687 remove old cmpi version definition
* Mon Sep 13 2010 kkaempf@novell.com
- Fix RHEL build
* Tue Oct  6 2009 mhrusecky@suse.cz
- updated to 1.1.0
  - fixes:
  * 1652246: fixes compile errors with gcc4
  * 1457924: various compile warnings
  * 1833455: updated URL for CPL
  * 2795176: migrate provider licenses to EPL
  - sblim-cmpi-nfsv3-1.0.13_gcc4.patch not needed anymore
* Tue May 12 2009 mhrusecky@suse.cz
- ignoring tog-pegasus during build
* Fri Sep 12 2008 mmarek@suse.cz
- switch to sfcb
* Thu Nov  1 2007 mmarek@suse.cz
- updated to 1.0.14
  fixed upstream bugs:
  * 1199129 Providers won't compile with CMPI 1.0
  * 1600348 Fixed association behaviour if /etc/exports
    file is empty
- removed static libs
* Thu Mar 29 2007 rguenther@suse.de
- add bison and flex BuildRequires
* Wed Mar  1 2006 mrueckert@suse.de
- update to 1.0.13 [#144214]
- dropped all patches as the build system changed
- added sblim-cmpi-nfsv3-1.0.13_gcc4.patch
  fixes a few compiler warnings in the lex/yacc generated code
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Dec  9 2005 mrueckert@suse.de
- build against openwbem
- use optflags
- fix the urgent compiler warnings
* Wed Apr 27 2005 ro@suse.de
- build with gcc-4
* Thu Nov 11 2004 ro@suse.de
- fixed file list
* Sun May 16 2004 nashif@suse.de
- #40661: SBLIM cmpi-nfsv3/4 reports error on empty
  /etc/exports file
- V 1.0.9
* Thu May 13 2004 nashif@suse.de
- #39756: cmpinfsv3 provider does not return associations for
  Linux_NFSv3SystemConfiguration class
- Do not De-register when updating package
* Mon May 10 2004 nashif@suse.de
- Dereigster providers when uninstalling (#39667)
- test scripts incorrectly check file read/write permission (#40262)
* Mon May 10 2004 nashif@suse.de
- Bug #39754:  wbemri & wbemrin fail to parse query results
  from Pegasus cimom
* Fri May  7 2004 nashif@suse.de
- Bug #39750: NFS providers not returning object path when
  creating new instance
* Fri Apr 30 2004 nashif@suse.de
- Update to version 1.0.2
- Fixed bug #39032: Copy utility library to /usr/lib
* Fri Apr 16 2004 nashif@suse.de
- Update version with bugfixes from IBM
* Wed Apr 14 2004 nashif@suse.de
- Added PreReq for loadmof.sh
* Wed Apr  7 2004 nashif@suse.de
- Initial Release
